@@ -16,7 +16,7 @@ class StateRepository(object):
         """to be implemented"""
         pass
 
-    def get_feature_names(self):
+    def get_feature_names(self) -> list:
         return [k for k in self.feature_states.keys()]
 
     def get_feature_states(self) -> dict:
